@@ -23,7 +23,7 @@ impl<'a> GetChannelWebhooks<'a> {
     /// [`Response`]: crate::response::Response
     pub fn exec(self) -> ResponseFuture<ListBody<Webhook>> {
         let request = Request::from_route(&Route::GetChannelWebhooks {
-            channel_id: self.channel_id.0,
+            channel_id: self.channel_id.get(),
         });
 
         self.http.request(request)
