@@ -6,13 +6,14 @@ use crate::{
     request::{
         self,
         validate_inner::{self, ComponentValidationError, ComponentValidationErrorType},
-        AuditLogReason, AuditLogReasonError, Form, NullableField, Request,
+        AttachmentFile, AuditLogReason, AuditLogReasonError, Form, NullableField, Request,
     },
     response::{marker::EmptyBody, ResponseFuture},
     routing::Route,
 };
 use serde::Serialize;
 use std::{
+    borrow::Cow,
     error::Error,
     fmt::{Display, Formatter, Result as FmtResult},
 };
@@ -169,8 +170,8 @@ struct UpdateWebhookMessageFields<'a> {
 /// [`DeleteWebhookMessage`]: super::DeleteWebhookMessage
 #[must_use = "requests must be configured and executed"]
 pub struct UpdateWebhookMessage<'a> {
+    attachments: Cow<'a, [AttachmentFile<'a>]>,
     fields: UpdateWebhookMessageFields<'a>,
-    files: &'a [(&'a str, &'a [u8])],
     http: &'a Client,
     message_id: MessageId,
     reason: Option<&'a str>,
@@ -197,7 +198,7 @@ impl<'a> UpdateWebhookMessage<'a> {
                 embeds: None,
                 payload_json: None,
             },
-            files: &[],
+            attachments: Cow::Borrowed(&[]),
             http,
             message_id,
             reason: None,
@@ -366,11 +367,22 @@ impl<'a> UpdateWebhookMessage<'a> {
         Ok(self)
     }
 
-    /// Attach multiple files to the webhook.
+    /// Attach multiple files to the message.
     ///
     /// Calling this method will clear any previous calls.
-    pub const fn files(mut self, files: &'a [(&'a str, &'a [u8])]) -> Self {
-        self.files = files;
+    #[allow(clippy::missing_const_for_fn)] // False positive
+    pub fn attach(mut self, attachments: &'a [AttachmentFile<'a>]) -> Self {
+        self.attachments = Cow::Borrowed(attachments);
+
+        self
+    }
+
+    /// Attach multiple files to the message.
+    ///
+    /// Calling this method will clear any previous calls.
+    #[deprecated(since = "0.7.2", note = "Use attach instead")]
+    pub fn files(mut self, files: &'a [(&'a str, &'a [u8])]) -> Self {
+        self.attachments = Cow::Owned(AttachmentFile::from_pairs(files));
 
         self
     }
@@ -400,11 +412,17 @@ impl<'a> UpdateWebhookMessage<'a> {
         })
         .use_authorization_token(false);
 
-        if !self.files.is_empty() || self.fields.payload_json.is_some() {
+        if !self.attachments.is_empty() || self.fields.payload_json.is_some() {
             let mut form = Form::new();
 
-            for (index, (name, file)) in self.files.iter().enumerate() {
-                form.file(format!("{}", index).as_bytes(), name.as_bytes(), file);
+            if !self.attachments.is_empty() {
+                for (index, attachment) in self.attachments.iter().enumerate() {
+                    form.attach(
+                        index as u64,
+                        attachment.filename.as_bytes(),
+                        attachment.file,
+                    );
+                }
             }
 
             if let Some(payload_json) = &self.fields.payload_json {
