@@ -1,11 +1,17 @@
 pub mod application;
 pub mod channel;
 pub mod guild;
-pub mod prelude;
 pub mod sticker;
 pub mod template;
 pub mod user;
 
+#[deprecated(
+    note = "this will be removed in a future major version",
+    since = "0.7.2"
+)]
+pub mod prelude;
+
+mod attachment;
 mod audit_reason;
 mod base;
 mod get_gateway;
@@ -22,6 +28,7 @@ mod multipart;
 mod validate_inner;
 
 pub use self::{
+    attachment::AttachmentFile,
     audit_reason::{AuditLogReason, AuditLogReasonError},
     base::{Request, RequestBuilder},
     get_gateway::GetGateway,
@@ -87,6 +94,13 @@ impl<T: Serialize> Serialize for NullableField<T> {
     }
 }
 
+#[derive(Serialize)]
+pub(crate) struct PartialAttachment<'a> {
+    pub description: Option<&'a str>,
+    pub filename: &'a str,
+    pub id: u64,
+}
+
 pub(crate) fn audit_header(
     reason: &str,
 ) -> Result<impl Iterator<Item = (HeaderName, HeaderValue)>, Error> {
