@@ -661,6 +661,13 @@ pub enum Route<'a> {
         /// The ID of the guild.
         guild_id: u64,
     },
+    /// Route information to get a member of a thread.
+    GetThreadMember {
+        /// ID of the thread.
+        channel_id: u64,
+        /// ID of the member.
+        user_id: u64,
+    },
     /// Route information to get members of a thread.
     GetThreadMembers {
         /// ID of the thread.
@@ -809,6 +816,11 @@ pub enum Route<'a> {
         /// The ID of the guild.
         guild_id: u64,
     },
+    /// Route information to update the current member.
+    UpdateCurrentMember {
+        /// ID of the guild.
+        guild_id: u64,
+    },
     /// Route information to update the current user.
     UpdateCurrentUser,
     /// Route information to update the current user's voice state.
@@ -1092,6 +1104,7 @@ impl<'a> Route<'a> {
             | Self::GetSticker { .. }
             | Self::GetTemplate { .. }
             | Self::GetTemplates { .. }
+            | Self::GetThreadMember { .. }
             | Self::GetThreadMembers { .. }
             | Self::GetUserConnections
             | Self::GetUserPrivateChannels
@@ -1101,6 +1114,7 @@ impl<'a> Route<'a> {
             | Self::GetWebhookMessage { .. }
             | Self::SearchGuildMembers { .. } => Method::Get,
             Self::UpdateChannel { .. }
+            | Self::UpdateCurrentMember { .. }
             | Self::UpdateCurrentUser
             | Self::UpdateCurrentUserVoiceState { .. }
             | Self::UpdateEmoji { .. }
@@ -1204,6 +1218,7 @@ impl<'a> Route<'a> {
                 Path::GuildsIdMembersIdRolesId(*guild_id)
             }
             Self::AddThreadMember { channel_id, .. }
+            | Self::GetThreadMember { channel_id, .. }
             | Self::GetThreadMembers { channel_id, .. }
             | Self::JoinThread { channel_id, .. }
             | Self::LeaveThread { channel_id, .. }
@@ -1361,7 +1376,9 @@ impl<'a> Route<'a> {
             }
             Self::GetGuildIntegrations { guild_id } => Path::GuildsIdIntegrations(*guild_id),
             Self::GetGuildInvites { guild_id } => Path::GuildsIdInvites(*guild_id),
-            Self::GetGuildMembers { guild_id, .. } => Path::GuildsIdMembers(*guild_id),
+            Self::GetGuildMembers { guild_id, .. } | Self::UpdateCurrentMember { guild_id, .. } => {
+                Path::GuildsIdMembers(*guild_id)
+            }
             Self::GetGuildPreview { guild_id } => Path::GuildsIdPreview(*guild_id),
             Self::GetGuildVanityUrl { guild_id } => Path::GuildsIdVanityUrl(*guild_id),
             Self::GetGuildVoiceRegions { guild_id } => Path::GuildsIdRegions(*guild_id),
