@@ -73,6 +73,10 @@ impl Display for RouteDisplay<'_> {
                 channel_id,
                 user_id,
             }
+            | Route::GetThreadMember {
+                channel_id,
+                user_id,
+            }
             | Route::RemoveThreadMember {
                 channel_id,
                 user_id,
@@ -1063,6 +1067,12 @@ impl Display for RouteDisplay<'_> {
 
                 f.write_str("sync")
             }
+            Route::UpdateCurrentMember { guild_id } => {
+                f.write_str("guilds/")?;
+                Display::fmt(guild_id, f)?;
+
+                f.write_str("/members/@me")
+            }
             Route::UpdateCurrentUserVoiceState { guild_id } => {
                 f.write_str("guilds/")?;
                 Display::fmt(guild_id, f)?;
@@ -1133,4 +1143,11 @@ mod tests {
             route.display().to_string()
         );
     }
+
+    #[test]
+    fn test_update_current_member() {
+        let route = Route::UpdateCurrentMember { guild_id: 1 };
+
+        assert_eq!("guilds/1/members/@me", route.display().to_string());
+    }
 }
